header {
    position:fixed;
    top: 0;
    left: 0;
    width: 100%;
}
body {
    background-color: linen;
    margin:auto;
    margin-top: auto;
    width:1024px;
    padding:10px;
    background-color:#ebebeb;
    font-size:14px;
    font-family:Verdana;
}
h1 {
    color: black;
}
th, td {
    padding-top: 5px;
    padding-left: 15px;
    padding-right: 20px;
}
ul {
    columns: 3;
}
